<?php

namespace app\command;

use app\model\UploadTaskModel;
use Exception;
use think\console\Command;
use think\console\Input;
use think\console\Output;
use think\db\exception\DbException;
use think\facade\Db;

/**
 * 合并上传的文件
 */
class UploadFileMerge extends Command
{
    private $tmp_dir;
    private $file_dir;

    public function __construct()
    {
        parent::__construct();
        $this->tmp_dir = env('upload.tmp_dir', '/u/tmp');
        $this->file_dir = env('upload.file_dir', '/u/f');
    }

    protected function configure()
    {
        $this->setName('UploadFileMerge')
            ->setDescription('合并上传的文件');
    }

    /**
     * @param Input $input
     * @param Output $output
     * @return void
     * @throws DbException
     */
    protected function execute(Input $input, Output $output)
    {
        $uploadTask = UploadTaskModel::where('status', 3)
            ->order('ut_id', 'asc')
            ->find();
        if (!empty($uploadTask)) {
            $output->writeln('有正在进行的合并任务');
            return;
        }

        $uploadTask = UploadTaskModel::where('status', 2)
            ->order('ut_id', 'asc')
            ->find();
        if (empty($uploadTask)) {
            $output->writeln('没有合并任务');
            return;
        }
        $param['ut_id'] = $uploadTask['ut_id'];
        UploadTaskModel::where('ut_id', $param['ut_id'])->save(['status' => 3]);

        $query = [];
        $query[] = ['ut_id', '=', $param['ut_id']];
        $list = Db::name('upload_task_chunk')->where($query)
            ->order('chunk', 'asc')->select();

        if ($uploadTask['chunks'] != count($list)) {
            UploadTaskModel::where('ut_id', $param['ut_id'])->save(['status' => 5]);
            $output->writeln('合并失败: 没有收到所有分片');
            return;
        }

        $output->writeln('开始合并');

        // 文件名
        $filename = $uploadTask['md5'] . '.' . $uploadTask['ext'];

        // 上传文件临时目录
        $path = root_path() . 'public' . $this->tmp_dir . '/' . date('Y_m_d', $uploadTask['create_time']) . '/' . $param['ut_id'];
        $filepath = $path . '/' . $filename;

        @unlink($filepath);
        $handle = fopen($filepath, 'x+');
        for ($i = 1; $i <= $uploadTask['chunks']; $i++) {
            $output->writeln("合并分片 $i");
            try {
                fwrite($handle, file_get_contents($path . '/' . $i));
            } catch (Exception $e) {
                UploadTaskModel::where('ut_id', $param['ut_id'])->save(['status' => 5]);
                $output->writeln("合并失败：第 $i 分片找不到");
                return;
            }
        }
        fclose($handle);

        // 计算文件 MD5
        ob_start(); // 防止命令执行的输出
        $last_line = system("md5sum $filepath | head -c 32");
        ob_end_clean(); // 防止命令执行的输出
        $output->writeln("合成文件 MD5: " . trim($last_line));
        $output->writeln("上传文件 MD5: " . $uploadTask['md5']);
        if (trim($last_line) != $uploadTask['md5']) {
            UploadTaskModel::where('ut_id', $param['ut_id'])->save(['status' => 5]);
            $output->writeln('合并失败：文件 MD5 校验不通过');
            return;
        }

        // 上传文件目录
        $path = root_path() . 'public' . $this->file_dir . '/' . date('Y_m_d', $uploadTask['create_time']) . '/' . $param['ut_id'];
        if (!is_dir($path)) mkdir($path, 0777, true);

        $toFilepath = $path . '/' . $filename;
        rename($filepath, $toFilepath);

        UploadTaskModel::where('ut_id', $param['ut_id'])->save([
            'status' => 4,
            'path' => $this->file_dir . '/' . date('Y_m_d', $uploadTask['create_time']) . '/' . $param['ut_id'] . '/' . $filename,
        ]);
        $output->writeln('合并完成');
    }
}