<?php

namespace app\controller;

use app\model\UploadTaskChunkModel;
use app\model\UploadTaskModel;
use app\validate\UploadTaskChunkValidate;
use app\validate\UploadTaskValidate;
use think\App;
use think\db\exception\DbException;
use think\facade\Db;
use think\facade\Request;
use think\response\Json;

/**
 * 处理文件上传
 */
class Upload extends Base
{
    private $tmp_dir;

    public function __construct(App $app)
    {
        parent::__construct($app);
        $this->tmp_dir = env('upload.tmp_dir', '/u/tmp');
    }

    /**
     * 添加上传任务
     * @return Json
     */
    public function addTask(): Json
    {
        $param['name'] = Request::param('name/s', '', 'trim');
        $param['size'] = Request::param('size/d');
        $param['chunks'] = Request::param('chunks/d');
        $param['md5'] = Request::param('md5/s', '', 'trim');
        $param['ext'] = pathinfo($param['name'], PATHINFO_EXTENSION);
        validate(UploadTaskValidate::class)->scene('add')->check($param);

        $uploadTask = UploadTaskModel::create([
            'name' => $param['name'],
            'size' => $param['size'],
            'chunks' => $param['chunks'],
            'md5' => $param['md5'],
            'ext' => $param['ext'],
        ]);
        return success($uploadTask, '添加成功');
    }

    /**
     * 添加分片信息
     * @return Json
     * @throws DbException
     */
    public function addChunk(): Json
    {
        $param['ut_id'] = Request::param('ut_id/d');
        $param['chunk'] = Request::param('chunk/d');
        $param['start'] = Request::param('start/d');
        $param['end'] = Request::param('end/d');
        $param['md5'] = Request::param('md5/s', '', 'trim');
        validate(UploadTaskChunkValidate::class)->scene('add')->check($param);

        $uploadTask = UploadTaskModel::where('ut_id', $param['ut_id'])->find();

        $file = request()->file('chunk');
        if ($param['md5'] != $file->md5()) return error([], '文件上传错误');

        // 上传文件临时目录
        $path = '.' . $this->tmp_dir . '/' . date('Y_m_d', $uploadTask['create_time']) . '/' . $param['ut_id'];
        if (!is_dir($path)) mkdir($path, 0777, true);

        // 移动分片文件到临时存储的位置
        $path = $path . '/' . $param['chunk'];
        move_uploaded_file($file->getPath() . '/' . $file->getFilename(), $path);

        $uploadTaskChunk = UploadTaskChunkModel::create([
            'ut_id' => $param['ut_id'],
            'chunk' => $param['chunk'],
            'start' => $param['start'],
            'end' => $param['end'],
            'md5' => $param['md5'],
            'path' => ltrim($path, '.'),
        ]);

        $uploadTask = UploadTaskModel::where('ut_id', $param['ut_id'])->find();
        if ($param['chunk'] == $uploadTask['chunks']) {
            UploadTaskModel::where('ut_id', $param['ut_id'])->save([
                'status' => 2,
            ]);
        }

        return success($uploadTaskChunk, '添加成功');
    }

    /**
     * 获得文件列表
     * @return Json
     * @throws DbException
     */
    public function list(): Json
    {
        $param['name'] = Request::param('name/s');
        $param['keyWords'] = Request::param('keyWords/s');

        $query = [];
        if ($param['name'] !== null && trim($param['name']) != '') $query[] = ['name', '=', trim($param['name'])];
        if ($param['keyWords'] !== null && trim($param['keyWords']) != '') $query[] = ['name', 'like', '%' . trim($param['keyWords']) . '%'];

        $paginator = Db::name('upload_task')->where($query)
            ->order(changeSort(Request::param('sort/a', []), ['ut_id' => 'desc']))
            ->paginate(Request::param('limit/d', 10))->toArray();
        return success($paginator, '查询成功');
    }
}