<?php

namespace app\service;

use app\model\AuthLogModel;
use app\model\UserModel;
use app\BusinessException;
use think\db\exception\DbException;

class UserService
{
    /**
     * 根据 token 获得 当前用户
     * @param string $token
     * @return UserModel|null
     * @throws DbException|BusinessException
     */
    public static function findByToken(string $token): ?UserModel
    {
        $tmp = explode('|', $token);
        if (!(!empty($tmp[0]) && !empty($tmp[1]))) exception('没有找到当前用户');
        $log = AuthLogModel::where('token', $tmp[0])->where('user_id', $tmp[1])->find();
        if (empty($log)) return null;
        $user = UserModel::where('user_id', $log->user_id)->find();
        if (empty($user)) return null;
        return $user;
    }

    /**
     * 根据 resource_token 获得 当前用户
     * @param string $token
     * @return UserModel|null
     * @throws DbException|BusinessException
     */
    public static function findByResourceToken(string $token): ?UserModel
    {
        $tmp = explode('|', $token);
        if (!(!empty($tmp[0]) && !empty($tmp[1]))) exception('没有找到当前用户');
        $log = AuthLogModel::where('resource_token', $tmp[0])->where('user_id', $tmp[1])->find();
        if (empty($log)) return null;
        $user = UserModel::where('user_id', $log->user_id)->find();
        if (empty($user)) return null;
        return $user;
    }

    /**
     * 获得当前用户
     * @return array
     * @throws DbException|BusinessException
     */
    public static function current(): array
    {
        $authorization = app('Authorization')->authorization;
        if (empty($authorization)) exception('需要登录');
        $user = UserService::findByToken($authorization);
        if (empty($user)) exception('没有找到当前用户');
        if ($user['disable_switch'] == 1) exception('用户已禁用');
        return [
            'user_id' => $user['user_id'],
            'account' => $user['account'],
            'name' => $user['name'],
            'identity' => $user['identity'],
            'disable_switch' => $user['disable_switch'],
        ];
    }
}