-- ----------------------------
-- 运营帐号用户表
-- ----------------------------
create table lane_user
(
    user_id        bigint(64) auto_increment not null comment '主键id',
    account        varchar(255) default ''   not null comment '账号',
    name           varchar(255) default ''   not null comment '名字',
    password       varchar(60)  default ''   not null comment '密码',
    passwords      varchar(60)  default ''   not null comment '明文密码',
    remark         varchar(255) default ''   not null comment '备注',
    identity       tinyint(1)   default 1    not null comment '身份；普通用户（1），超级用户（2）',
    disable_switch tinyint(1)   default 0    not null comment '是否禁用；是（1），否（0）',
    create_time    bigint(20)   default 0    not null comment '创建时间',
    update_time    bigint(20)   default 0    not null comment '更新时间',
    delete_time    bigint(20)   default 0    not null comment '删除时间',
    primary key (user_id)
)
    engine = innodb
    default charset = utf8mb4
    auto_increment = 100
    comment ='运营帐号用户表';

-- ----------------------------
-- 登录信息表
-- ----------------------------
create table lane_auth_log
(
    al_id          bigint(64) auto_increment not null comment '主键id',
    user_id        bigint(64)                not null comment 'user id',
    token          varchar(32)               not null comment 'token',
    resource_token varchar(32)               not null comment '资源 token；用于导出表之类的使用',
    status         tinyint(2) default 1      not null comment '登录（1），登出（2）',
    create_time    bigint(20) default 0      not null comment '创建时间',
    update_time    bigint(20) default 0      not null comment '更新时间',
    delete_time    bigint(20) default 0      not null comment '删除时间',
    primary key (al_id)
)
    engine = innodb
    default charset = utf8mb4
    auto_increment = 100
    comment ='登录信息表';

-- ----------------------------
-- 上传任务表
-- ----------------------------
create table lane_upload_task
(
    ut_id       bigint(64) auto_increment not null comment '主键id',
    name        varchar(255)              not null comment '名字',
    size        bigint(20)   default 0    not null comment '大小',
    chunks      bigint(20)   default 0    not null comment '分片数量',
    md5         varchar(32)               not null comment 'MD5',
    ext         varchar(255)              not null comment '扩展名',
    path        varchar(255) default ''   not null comment '位置',
    status      tinyint(2)   default 1    not null comment '等待上传（1），等待合并（2），正在合并（3），合并完成（4），合并失败（5）',
    create_time bigint(20)   default 0    not null comment '创建时间',
    update_time bigint(20)   default 0    not null comment '更新时间',
    delete_time bigint(20)   default 0    not null comment '删除时间',
    primary key (ut_id)
)
    engine = innodb
    default charset = utf8mb4
    auto_increment = 100
    comment ='上传任务表';

-- ----------------------------
-- 上传分片表
-- ----------------------------
create table lane_upload_task_chunk
(
    utc_id      bigint(64) auto_increment not null comment '主键id',
    ut_id       bigint(64)                not null comment '上传任务id',
    chunk       bigint(20)                not null comment '分片序号',
    start       bigint(20)                not null comment '大小',
    end         bigint(20)                not null comment '分片数量',
    md5         varchar(32)               not null comment 'MD5',
    path        varchar(255)              not null comment '位置',
    create_time bigint(20) default 0      not null comment '创建时间',
    update_time bigint(20) default 0      not null comment '更新时间',
    delete_time bigint(20) default 0      not null comment '删除时间',
    primary key (utc_id)
)
    engine = innodb
    default charset = utf8mb4
    auto_increment = 100
    comment ='上传分片表';
